import {localeOptions, localeProps} from '../../utils';

const label = '数据表格';
const name = 'dataTable';

const makeData = () => {
    const data = [];
    for (let i = 0; i < 30; i++) {
        data.push({
            date: '2016-05-12',
            name: 'Tom ' + (10 + i),
            state: 'California',
            city: 'Los Angeles',
            address: 'No. 189, Grove St, Los Angeles',
            zip: 'CA 90036',
        })
    }
    return data;
}

export default {
    menu: 'main',
    icon: 'icon-data-table',
    label,
    name,
    languageKey: ['operation'],
    event: ['handleClick', 'change', 'rowSelectionChange'],
    sfc: false,
    rule() {
        return {
            type: name,
            native: true,
            props: {
                scroll: {x: '1000px', y: '500px'},
                button: {},
                data: makeData(),
                column: [{
                    'format': 'default', 'prop': 'date', 'label': 'Date', width: '150'
                }, {
                    'format': 'default', 'prop': 'name', 'label': 'Name', width: '120'
                }, {
                    'format': 'default', 'prop': 'state', 'label': 'State', width: '120'
                }, {
                    'format': 'default', 'prop': 'city', 'label': 'City', width: '320'
                }, {
                    'format': 'default', 'prop': 'address', 'label': 'Address', width: '600'
                }, {
                    'format': 'default', 'prop': 'zip', 'label': 'Zip', width: '120'
                }]
            },
        };
    },
    props(_, {t}) {
        const propsT = function (list) {
            return localeProps(t, name + '.props', list);
        }
        const rule1 = propsT([{
            type: 'input', field: 'page>totalField', value: 'count',
        }, {
            type: 'input', field: 'page>dataField', value: 'list',
        }, {
            type: 'input', field: 'page>orderField', value: 'order',
        }, {
            type: 'input', field: 'page>orderByField', value: 'orderBy',
        }, {
            type: 'input', field: 'page>pageField', value: 'page',
        }, {
            type: 'input',
            field: 'page>pageSizeField',
            value: 'limit',
        }]);

        return localeProps(t, name + '.props', [{
            type: 'radio',
            field: '_optionType',
            value: 0,
            options: [
                {'label': t('fetch.optionsType.struct'), 'value': 0},
                {'label': t('fetch.optionsType.fetch'), 'value': 2},
                {'label': t('fetch.optionsType.global'), 'value': 1},
            ],
            props: {
                optionType: 'button'
            },
            control: [{
                value: 1,
                rule: [{
                    type: 'GlobalFetchSelect', field: 'globalDataKey',
                }, ...rule1]
            }, {
                value: 2,
                rule: [{
                    type: 'FetchConfig', field: 'fetch',
                }, ...rule1]
            }, {
                value: 0,
                rule: [{
                    type: 'Struct',
                    title: t('com.dataTable.props._optionType'),
                    field: 'data',
                    _fc_important_prop: true,
                    props: {
                        validate(val) {
                            return !val || Array.isArray(val);
                        }
                    }
                }],
            }]
        }, {
            type: 'TableColumnConfig',
            field: 'column',
            _fc_important_prop: true,
        }, {
            type: 'select', field: 'size',
            options: localeOptions(t, [
                {label: 'default', value: 'default'},
                {label: 'small', value: 'small'}
            ])
        }, {
            type: 'ConfigItem', props: {
                label: t('com.dataTable.props.button')
            }, col: {
                show: true
            }, children: [{
                type: 'HideConfig',
                title: t('com.dataTable.props.button'),
                wrap: {show: false},
                col: {show: false},
                field: 'button>open'
            }, {
                type: 'template',
                slot: 'append',
                children: propsT([{
                    type: 'TableButtonConfig',
                    col: {show: false},
                    field: 'button>column',
                }, {
                    type: 'input',
                    col: {show: false},
                    field: 'button>label',
                    value: '操作'
                }, {
                    type: 'select',
                    col: {show: false},
                    field: 'button>fixed',
                    options: [
                        {label: t('com.dataTable.fixed.default'), value: false},
                        {label: t('com.dataTable.fixed.right'), value: 'right'}
                    ],
                    value: 'right',
                }, {
                    type: 'SizeInput',
                    col: {show: false},
                    field: 'button>width',
                    value: '125px'
                },])
            }]
        }, {
            type: 'ConfigItem',
            props: {
                label: t('com.dataTable.props.page')
            }, col: {
                show: true
            }, children: [{
                type: 'HideConfig',
                wrap: {
                    show: false
                },
                col: {
                    show: false
                },
                title: t('com.dataTable.props.page'),
                field: 'page>open'
            }, {
                type: 'template',
                slot: 'append',
                children: propsT([{
                    type: 'select',
                    field: 'page>position',
                    value: 'right',
                    col: {
                        show: false
                    },
                    options: localeOptions(t, [
                        {
                            label: 'left', value: 'left',
                        },
                        {
                            label: 'center', value: 'center',
                        },
                        {
                            label: 'right', value: 'right',
                        }
                    ])
                }, {
                    type: 'inputNumber',
                    col: {
                        show: false
                    },
                    field: 'page>props>pageSize',
                    value: 20,
                }, {
                    type: 'select',
                    col: {
                        show: false
                    },
                    field: 'page>props>size',
                    options: localeOptions(t, [
                        {
                            label: 'default', value: 'default',
                        },
                        {
                            label: 'small', value: 'small',
                        },
                    ])
                }])
            }]
        }, {
            type: 'input', field: 'rowKey',
        }, {
            type: 'switch', field: 'selection',
        }, {
            type: 'SizeInput', field: 'scroll>x',
        }, {
            type: 'SizeInput', field: 'scroll>y',
        }, {
            type: 'switch', field: 'bordered',
        }]);
    }
};
