import is from '@form-create/utils/lib/type';

const findTreeLabel = function (find, data, key, label) {
    data.forEach(v => {
        if (find.indexOf(v[key || 'id']) > -1) {
            find.splice(find.indexOf(v[key || 'id']), 1, v[label || 'label']);
        }
        if (is.trueArray(v.children)) {
            findTreeLabel(find, v.children, key, label);
        }
    });
    return find;
};

const findCheckboxLabel = function (find, data) {
    data.forEach(v => {
        if (find.indexOf(v.value) > -1) {
            find[find.indexOf(v.value)] = v.label;
        }
    });
    return find;
};

function toArray(val) {
    if (!val) {
        return [];
    } else if (!Array.isArray(val)) {
        return [val];
    }
    return val;
}

export default function renderPreview(_, ctx) {
    let val = ctx.rule.value;
    const h = ctx.$render.vNode.h;
    const type = ctx.type;
    const subForm = ctx.$handle.subForm[ctx.id];
    const readMode = ctx.prop.readMode;
    if (ctx.prop.title.title && ctx.prop.title.title.trim()) {
        ctx.prop.title.title += '：';
    }
    // ctx.prop.wrap.labelWidth = '100px';
    if (readMode === false || readMode === 'custom' || !ctx.input || ctx.rule.subForm || (Array.isArray(subForm) ? subForm.length : subForm) || ['fcGroup', 'fcSubForm', 'tableForm', 'stepForm', 'nestedTableForm', 'infiniteTableForm', 'fcUpload'].indexOf(ctx.trueType) > -1) {
        return ctx.parser.render(_, ctx);
    }
    if (['radio', 'select', 'checkbox'].indexOf(type) > -1) {
        val = findCheckboxLabel([...toArray(val)], ctx.prop.props.options || ctx.prop.props.formCreateInject.options || []).join(', ');
    } else if (['timePicker', 'datePicker', 'slider'].indexOf(type) > -1) {
        val = Array.isArray(val) ? val.join(' - ') : val;
    } else if (type === 'cascader') {
        val = [...toArray(val)];
        if (!Array.isArray(val[0])) {
            val = [val];
        }
        val = val.map(item => {
            return findTreeLabel(item, ctx.prop.props.options || ctx.prop.props.formCreateInject.options || [], 'value').join('/');
        }).join(', ');
    } else if (type === 'aTransfer') {
        const value = [...toArray(val)];
        val = findTreeLabel(value, ctx.prop.props.dataSource || ctx.prop.props.formCreateInject.options || [], 'key').join(', ');
    } else if (['tree', 'aTreeSelect'].indexOf(type) > -1) {
        const data = ctx.prop.props.treeData || ctx.prop.props.formCreateInject.options || [];
        val = findTreeLabel([...toArray(val)], data, type === 'aTreeSelect' ? 'value' : 'id').join(', ');
    } else if (type === 'fcEditor' || readMode === 'html') {
        return h('div', {innerHTML: val});
    } else if (readMode === 'image') {
        val = toArray(val);
        return h('div', {class: '_fc-upload'}, [
            h('a-image-preview-group', {}, {
                default: () => val.map(function (item) {
                    return h('div', {class: '_fc-upload-preview'}, [
                        h('a-image', {style: {height: '100%'}, src: typeof item === 'object' ? item.url : item})
                    ]);
                })
            })
        ]);
    } else if ((type === 'switch' || type === 'a-switch') && (null != ctx.prop.props.checkedValue || null != ctx.prop.props.unCheckedValue)) {
        val = ctx.prop.props.checkedValue === val ? '是' : '否'
    } else if (type === 'signaturePad' && val) {
        return h('a-image', {src: val, fit: 'cover', style: {height: '90px'}});
    } else if (typeof val === 'boolean') {
        val = val ? '是' : '否';
    }

    return h('span', {class: '_fc-read-view'}, ['' + (val == null ? '' : val)]);
}